==> gitlab-18.0.1-1-x86_64.pkg.tar.zst: usr/share/webapps/gitlab/.gitlab/issue_templates/Workspaces Category - issue.md <==
MR: Pending

<!-- NOTE: For context on MR heading, see:
https://handbook.gitlab.com/handbook/engineering/development/dev/create/remote-development/index.html#relationship-of-issues-to-mrs
-->

## Description

TODO: Fill out (required)

As a [user or stakeholder], I want [goal or objective] so that [reason or benefit].

<!-- TODO: What kind of issue is this? Please uncomment and include one of the following:

/label ~"type::feature"
/label ~"type::bug"
/label ~"type::maintenance"
-->

<!-- OPTIONAL: Is this a feature/enhancement?

- Please describe the impact this feature/enhancement will have on the user experience and/or the product as a whole.
- Provide a user story to illustrate the use case for this feature/enhancement. Include examples to help communicate the intended functionality.
-->

<!-- OPTIONAL: Is this a bug? Please uncomment and include the following:

- **Current behavior:**
- **Expected behavior:**
- **Steps to reproduce:**
- **Additional information:** please include VSCode version, browser dev tool logs, etc that might be helpful to debug the issue!
-->

## Acceptance criteria

TODO: Fill out (required)

- [ ] [Describe what must be achieved to complete this issue.]
- [ ] [If applicable, please provide design specifications for this feature/enhancement.]
- [ ] [If applicable, please list any technical requirements (performance, security, database, etc.)]

## Implementation plan

TODO: Fill out or delete (optional)  
[Provide a high-level plan for implementation of this issue, including relevant technical and/or design details.]

<!-- NOTE: Feel free to expand with more sections and headers as needed -->

<!-- DO NOT TOUCH BELOW -->

/label ~"Category:Workspaces"
/label ~"section::dev"
/label ~"devops::create"
/label ~"group::remote development"
/label ~"workspaces-workflow::unprioritized"
/label ~"workflow::refinement"

==> gitlab-18.5.1-1-x86_64.pkg.tar.zst: usr/share/webapps/gitlab/.gitlab/issue_templates/Workspaces Category - issue.md <==
MR: Pending

<!-- NOTE: For context on MR heading, see:
https://handbook.gitlab.com/handbook/engineering/devops/dev/create/remote-development/index.html#relationship-of-issues-to-mrs
-->

## Description

TODO: Fill out (required)

As a [user or stakeholder], I want [goal or objective] so that [reason or benefit].

<!-- TODO: What kind of issue is this? Please uncomment and include one of the following:

/label ~"type::feature"
/label ~"type::bug"
/label ~"type::maintenance"
-->

<!-- OPTIONAL: Is this a feature/enhancement?

- Please describe the impact this feature/enhancement will have on the user experience and/or the product as a whole.
- Provide a user story to illustrate the use case for this feature/enhancement. Include examples to help communicate the intended functionality.
-->

<!-- OPTIONAL: Is this a bug? Please uncomment and include the following:

- **Current behavior:**
- **Expected behavior:**
- **Steps to reproduce:**
- **Additional information:** please include VSCode version, browser dev tool logs, etc that might be helpful to debug the issue!
-->

## Acceptance criteria

TODO: Fill out (required)

- [ ] [Describe what must be achieved to complete this issue.]
- [ ] [If applicable, please provide design specifications for this feature/enhancement.]
- [ ] [If applicable, please list any technical requirements (performance, security, database, etc.)]

## Implementation plan

TODO: Fill out or delete (optional)

[Provide a high-level plan for implementation of this issue, including relevant technical and/or design details.]

<!-- NOTE: Feel free to expand with more sections and headers as needed -->

<!-- DO NOT TOUCH BELOW -->

/label ~"Category:Workspaces"
/label ~"section::dev"
/label ~"devops::create"
/label ~"group::remote development"
/label ~"workflow::refinement"

/milestone %Backlog
